==> helm-annotations-4.0.0-sources.jar: io/dekorate/helm/config/ValuesSchema.java <==
package io.dekorate.helm.config;

import java.lang.Object;
import java.lang.String;
import io.sundr.builder.annotations.Buildable;

 /**
  * Generated
  */
  @Buildable(refs = {@io.sundr.builder.annotations.BuildableReference(value = io.dekorate.project.Project.class),@io.sundr.builder.annotations.BuildableReference(value = io.dekorate.project.BuildInfo.class)} ,builderPackage = "io.fabric8.kubernetes.api.builder")
  public class ValuesSchema{
  public ValuesSchema() {
  }
  public ValuesSchema(String title,ValuesSchemaProperty[] properties) {
    this.title = title;
    this.properties = properties != null ? properties : new ValuesSchemaProperty[0];
  }
  private String title;
  private ValuesSchemaProperty[] properties = new ValuesSchemaProperty[0];
  public String getTitle() {
    return this.title;
  }
  public ValuesSchemaProperty[] getProperties() {
    return this.properties;
  }
  public static ValuesSchemaBuilder newBuilder() {
    return new ValuesSchemaBuilder();
  }
  public static ValuesSchemaBuilder newBuilderFromDefaults() {
    return new ValuesSchemaBuilder().withTitle("Values");
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValuesSchema that = (ValuesSchema) o;
    if (!java.util.Objects.equals(title, that.title)) return false;

    if (!java.util.Objects.equals(properties, that.properties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(title,  properties,  super.hashCode());
  }
  
}

==> helm-annotations-4.0.3-sources.jar: io/dekorate/helm/config/ValuesSchema.java <==
package io.dekorate.helm.config;

import java.lang.Object;
import java.lang.String;
import io.sundr.builder.annotations.Buildable;

/**
 * Generated
 */
@Buildable(refs = {@io.sundr.builder.annotations.BuildableReference(io.dekorate.project.Project.class),@io.sundr.builder.annotations.BuildableReference(io.dekorate.project.BuildInfo.class)} ,builderPackage = "io.fabric8.kubernetes.api.builder")
public class ValuesSchema{
  public ValuesSchema() {
  }
  
  public ValuesSchema(String title,ValuesSchemaProperty[] properties) {
    this.title = title;
    this.properties = properties != null ? properties : new ValuesSchemaProperty[0];
  }
  private String title;
  private ValuesSchemaProperty[] properties = new ValuesSchemaProperty[0];
  
  public String getTitle() {
    return this.title;
  }
  
  public ValuesSchemaProperty[] getProperties() {
    return this.properties;
  }
  
  public static ValuesSchemaBuilder newBuilder() {
    return new ValuesSchemaBuilder();
  }
  
  public static ValuesSchemaBuilder newBuilderFromDefaults() {
    return new ValuesSchemaBuilder().withTitle("Values");
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValuesSchema that = (ValuesSchema) o;
    if (!java.util.Objects.equals(title, that.title)) return false;
    if (!java.util.Objects.equals(properties, that.properties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(title,  properties,  super.hashCode());
  }
  

}
